import type IGame from "../api/types/IGame.ts";
import {
    Accordion,
    AccordionDetails,
    AccordionSummary, CircularProgress,
    Stack, Tooltip, Typography
} from "@mui/joy";
import type IPlayer from "../api/types/IPlayer.ts";
import {useContext, useEffect, useState} from "react";
import {GetPlayersOfGame} from "../api/endpoints/Data.tsx";
import {ApiUriContext} from "../api/fetchApi.tsx";
import PlayerCard from "./PlayerCard.tsx";

export default function GameAccordionItem({game, OpenPlayerGameStatsDrawer} : {game: IGame, OpenPlayerGameStatsDrawer : (player: IPlayer, game: IGame) => void}) {
    const apiUri = useContext(ApiUriContext);

    const [players, setPlayers] = useState<IPlayer[]>([]);
    const [expanded, setExpanded] = useState<boolean>(false);
    const [loading, setLoading] = useState<boolean>(false);

    useEffect(() => {
        if(!expanded)
            return;
        setLoading(true);
        GetPlayersOfGame(apiUri, game.appId)
            .then(setPlayers)
            .finally(() => setLoading(false));
    }, [expanded]);

    return (
        <Accordion key={game.appId} onChange={(_, expanded) => setExpanded(expanded)}>
            <AccordionSummary>
                <img src={game.iconUrl??"favicon.ico"} />
                <Tooltip title={game.appId}>
                    <Typography level={"h4"}>{game.name}</Typography>
                </Tooltip>
            </AccordionSummary>
            <AccordionDetails>
                <Stack flexWrap={"wrap"} direction={"row"} spacing={1} useFlexGap>
                    {loading
                        ? <CircularProgress />
                        : players?.map((player) => <PlayerCard key={player.steamId} player={player} onClick={() => OpenPlayerGameStatsDrawer(player, game)} />)}
                </Stack>
            </AccordionDetails>
        </Accordion>
    );
}