import type IGame from "../api/types/IGame.ts";
import {
    Accordion,
    AccordionDetails,
    AccordionSummary, Button, CircularProgress,
    Stack, Tooltip, Typography
} from "@mui/joy";
import type IPlayer from "../api/types/IPlayer.ts";
import {useContext, useEffect, useState} from "react";
import {ApiUriContext} from "../api/fetchApi.tsx";
import {GetGamesOfPlayer} from "../api/endpoints/Data.tsx";
import GameCard from "./GameCard.tsx";
import {GetTotal} from "../api/endpoints/TimeTrack.tsx";

export default function PlayerAccordionItem({player, OpenPlayerGameStatsDrawer, OpenPlayerStatsDrawer} : {player: IPlayer, OpenPlayerGameStatsDrawer : (player: IPlayer, game: IGame) => void, OpenPlayerStatsDrawer : (player: IPlayer) => void}) {
    const apiUri = useContext(ApiUriContext);

    const [games, setGames] = useState<IGame[]>([]);
    const [expanded, setExpanded] = useState<boolean>(false);
    const [loadingGames, setLoadingGames] = useState<boolean>(false);
    const [totalTime, setTotalTime] = useState<bigint>(BigInt(0));

    useEffect(() => {
        if(!expanded)
            return;
        setLoadingGames(true);
        GetGamesOfPlayer(apiUri, player.steamId)
            .then(setGames)
            .finally(() => setLoadingGames(false));
        GetTotal(apiUri, player.steamId)
            .then(setTotalTime)
    }, [expanded]);

    return (
        <Accordion key={player.steamId} onChange={(_, expanded) => setExpanded(expanded)}>
            <AccordionSummary>
                <img src={player.avatarUrl} />
                <Tooltip title={player.steamId}>
                    <Typography level={"h4"}>{player.name}</Typography>
                </Tooltip>
            </AccordionSummary>
            <AccordionDetails>
                <Stack flexWrap={"nowrap"} direction={"row"} alignContent={"center"} spacing={2} useFlexGap marginBottom={"10px"}>
                    <Button onClick={() => OpenPlayerStatsDrawer(player)}>All Games</Button>
                    <Typography level={"h4"} >Total Time: {totalTime}</Typography>
                </Stack>
                <Stack flexWrap={"wrap"} direction={"row"} spacing={1} useFlexGap>
                    {loadingGames
                        ? <CircularProgress />
                        : games?.map((game) => <GameCard key={game.appId} game={game} onClick={() => OpenPlayerGameStatsDrawer(player, game)} />)}
                </Stack>
            </AccordionDetails>
        </Accordion>
    );
}